@@ -2,11 +2,12 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, ModelSingleton, fields
 
+__all__ = ['Configuration']
+
 
 class Configuration(ModelSingleton, ModelSQL, ModelView):
     'Party Configuration'
-    _name = 'party.configuration'
-    _description = __doc__
+    __name__ = 'party.configuration'
 
     party_sequence = fields.Property(fields.Many2One('ir.sequence',
             'Party Sequence', domain=[
@@ -15,5 +16,3 @@ class Configuration(ModelSingleton, ModelSQL, ModelView):
     party_lang = fields.Property(fields.Many2One("ir.lang", 'Party Language',
         help=('The value set on this field will preset the language on new '
             'parties')))
-
-Configuration()
